@@ -140,7 +140,9 @@ def boxplot(ax, x, **kwargs):
         kwargs.pop('xticklabels')
     else:
         xticklabels = None
-    bp = ax.boxplot(x, widths=0.15, **kwargs)
+    if 'widths' not in kwargs:
+        kwargs['widths'] = 0.15
+    bp = ax.boxplot(x, **kwargs)
     if xticklabels:
         ax.xaxis.set_ticklabels(xticklabels)
 
